Documentation
¶
Overview ¶
Package keymanage defines the interface of Key Management Algorithms.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Algorithm ¶
type Algorithm interface {
NewKeyWrapper(key Key) KeyWrapper
}
Algorithm is an algorithm for wrapping or unwrapping Content Encryption Key (CEK).
type Key ¶
type Key interface {
PrivateKey() crypto.PrivateKey
PublicKey() crypto.PublicKey
}
Key is a key for wrapping or unwrapping Content Encryption Key (CEK).
type KeyDeriver ¶
type KeyWrapper ¶
type KeyWrapper interface {
WrapKey(cek []byte, opts any) (data []byte, err error)
UnwrapKey(data []byte, opts any) (cek []byte, err error)
}
func NewInvalidKeyWrapper ¶
func NewInvalidKeyWrapper(err error) KeyWrapper
Click to show internal directories.
Click to hide internal directories.